Report available CPU cores for parallel execution
timefish_available_cores.RdReturns the number of physical CPU cores detected by the current R session. This value is used by timefishr functions that support parallel execution.
timefish_available_cores.RdReturns the number of physical CPU cores detected by the current R session. This value is used by timefishr functions that support parallel execution.