Skip to contents

Use this helper when you want to filter a numeric column by an inclusive range, for example years.

Usage

timefish_between(from, to = from)

Arguments

from

Lower bound.

to

Upper bound. Defaults to from, so timefish_between(2020) filters a single year.

Value

A range object that can be passed to timefish_query().

Examples

timefish_between(2007, 2010)
#> $from
#> [1] 2007
#> 
#> $to
#> [1] 2010
#> 
#> attr(,"class")
#> [1] "timefish_range"
timefish_between(2020)
#> $from
#> [1] 2020
#> 
#> $to
#> [1] 2020
#> 
#> attr(,"class")
#> [1] "timefish_range"