Skip to contents

This helper standardises sampling effort by locality using a transect-level table and returns summary tables for users to inspect before bootstrap or sub-sampling workflows.

Usage

timefish_minimum_sampling_area(
  data,
  area_col,
  transect_id_col,
  site_col,
  location_col,
  save_minimum = FALSE,
  ask_save = FALSE
)

Arguments

data

A data frame with transect-level identifiers (or repeated rows that contain a transect identifier).

area_col

Column name with transect area values.

transect_id_col

Column name with the unique transect identifier.

site_col

Column name for site.

location_col

Column name for locality (for example island/location).

save_minimum

Logical. If TRUE, save the estimated minimum area in options(timefishr.minimum_sampling_area = <value>).

ask_save

Logical. If TRUE and interactive, ask the user whether to save the estimated minimum area in options.

Value

A list with minimum_area, reference_locations, by_location, by_location_site, and transects.

Examples

min_area <- timefish_minimum_sampling_area(
  data = timefish_location(),
  area_col = "sampling_area_m2",
  transect_id_col = "transect_id",
  site_col = "site",
  location_col = "location"
)