Path to a TimeFish table
timefish_path.RdReturns the local file path for one of the bundled TimeFish CSV files.
Usage
timefish_path(table = c("census", "location", "taxonomic"))timefish_path.RdReturns the local file path for one of the bundled TimeFish CSV files.
timefish_path(table = c("census", "location", "taxonomic"))